Returns the file path to the BHF Stan model included in the package.
This is useful if you want to inspect or modify the model code.
Value
Character string with the path to the Stan file.
Examples
# Get the path
stan_path <- get_stan_file_path()
print(stan_path)
#> [1] "/private/var/folders/22/41f2lr_j0rz4yfdj76vg19m80000gq/T/RtmpqdSm02/temp_libpathbe5b14365fc3/bhfvar/stan/bhf_hybrid.stan"
# Read and view the model code
if (FALSE) { # \dontrun{
cat(readLines(stan_path), sep = "\n")
} # }