Extracts the log-likelihood matrix for use with the loo package for leave-one-out cross-validation.
Arguments
- fit
An object of class
bhf_fitfrombhf_fit().
Extracts the log-likelihood matrix for use with the loo package for leave-one-out cross-validation.
An object of class bhf_fit from bhf_fit().